AVAudio3DAngularOrientation

Struct AVAudio3DAngularOrientation 

#[repr(C)]
pub struct AVAudio3DAngularOrientation { pub yaw: c_float, pub pitch: c_float, pub roll: c_float, }
Available on crate feature AVAudioTypes only.
Struct representing the orientation of the listener in 3D space

Three angles describe the orientation of a listener’s head - yaw, pitch and roll.

Yaw describes the side to side movement of the listener’s head. The yaw axis is perpendicular to the plane of the listener’s ears with its origin at the center of the listener’s head and directed towards the bottom of the listener’s head. A positive yaw is in the clockwise direction going from 0 to 180 degrees. A negative yaw is in the counter-clockwise direction going from 0 to -180 degrees.

Pitch describes the up-down movement of the listener’s head. The pitch axis is perpendicular to the yaw axis and is parallel to the plane of the listener’s ears with its origin at the center of the listener’s head and directed towards the right ear. A positive pitch is the upwards direction going from 0 to 180 degrees. A negative pitch is in the downwards direction going from 0 to -180 degrees.

Roll describes the tilt of the listener’s head. The roll axis is perpendicular to the other two axes with its origin at the center of the listener’s head and is directed towards the listener’s nose. A positive roll is to the right going from 0 to 180 degrees. A negative roll is to the left going from 0 to -180 degrees.

See also Apple’s documentation

Fields

yaw: c_floatpitch: c_floatroll: c_float