AVAudio3DVectorOrientation

Struct AVAudio3DVectorOrientation 

#[repr(C)]
pub struct AVAudio3DVectorOrientation { pub forward: AVAudio3DVector, pub up: AVAudio3DVector, }
Available on crate feature AVAudioTypes only.
Struct representing the orientation of the listener in 3D space

Two orthogonal vectors describe the orientation of the listener. The forward vector points in the direction that the listener is facing. The up vector is orthogonal to the forward vector and points upwards from the listener’s head.

See also Apple’s documentation

Fields

forward: AVAudio3DVectorup: AVAudio3DVector