#[repr(transparent)]pub struct AVAudioApplicationMicrophoneInjectionPermission(pub NSInteger);Available on crate feature
AVAudioApplication only.Expand description
These are the values returned by microphoneInjectionPermission.
The user has disabled this service for all apps.
The user has not yet been asked for permission.
The user has been asked and has denied permission.
The user has been asked and has granted permission.
Introduced: ios(18.2) visionos(2.2)
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl AVAudioApplicationMicrophoneInjectionPermission
impl AVAudioApplicationMicrophoneInjectionPermission
pub const ServiceDisabled: Self
pub const Undetermined: Self
pub const Denied: Self
pub const Granted: Self