#[repr(transparent)]pub struct AVAudioApplicationRecordPermission(pub NSInteger);Available on crate feature
AVAudioApplication only.Expand description
These are the values returned by recordPermission.
The user has not yet been asked for permission.
The user has been asked and has denied permission.
The user has been asked and has granted permission.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations