pub struct AVAudioConnectionPoint { /* private fields */ }AVAudioConnectionPoint only.Expand description
A representation of either a source or destination connection point in AVAudioEngine.
AVAudioConnectionPoint describes either a source or destination connection point (node, bus) in AVAudioEngine’s graph.
Instances of this class are immutable.
See also Apple’s documentation
Implementations
Sourceimpl AVAudioConnectionPoint
impl AVAudioConnectionPoint
Sourcepub unsafe fn initWithNode_bus(
this: Allocated<Self>,
node: &AVAudioNode,
bus: AVAudioNodeBus,
) -> Retained<Self>
Available on crate features AVAudioNode and AVAudioTypes only.
pub unsafe fn initWithNode_bus( this: Allocated<Self>, node: &AVAudioNode, bus: AVAudioNodeBus, ) -> Retained<Self>
AVAudioNode and AVAudioTypes only.Create a connection point object.
Parameter node: the source or destination node
Parameter bus: the output or input bus on the node
If the node is nil, this method fails (returns nil).
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn node(&self) -> Option<Retained<AVAudioNode>>
Available on crate feature AVAudioNode only.
pub unsafe fn node(&self) -> Option<Retained<AVAudioNode>>
AVAudioNode only.Returns the node in the connection point.
Sourcepub unsafe fn bus(&self) -> AVAudioNodeBus
Available on crate feature AVAudioTypes only.
pub unsafe fn bus(&self) -> AVAudioNodeBus
AVAudioTypes only.Returns the bus on the node in the connection point.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for AVAudioConnectionPoint
impl AsRef<AnyObject> for AVAudioConnectionPoint
Sourceimpl AsRef<NSObject> for AVAudioConnectionPoint
impl AsRef<NSObject> for AVAudioConnectionPoint
Sourceimpl Borrow<AnyObject> for AVAudioConnectionPoint
impl Borrow<AnyObject> for AVAudioConnectionPoint
Sourceimpl Borrow<NSObject> for AVAudioConnectionPoint
impl Borrow<NSObject> for AVAudioConnectionPoint
Sourceimpl ClassType for AVAudioConnectionPoint
impl ClassType for AVAudioConnectionPoint
Sourceconst NAME: &'static str = "AVAudioConnectionPoint"
const NAME: &'static str = "AVAudioConnectionPoint"
Sourcetype ThreadKind = <<AVAudioConnectionPoint as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<AVAudioConnectionPoint as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for AVAudioConnectionPoint
impl Debug for AVAudioConnectionPoint
Sourceimpl Deref for AVAudioConnectionPoint
impl Deref for AVAudioConnectionPoint
Sourceimpl Hash for AVAudioConnectionPoint
impl Hash for AVAudioConnectionPoint
Sourceimpl Message for AVAudioConnectionPoint
impl Message for AVAudioConnectionPoint
Sourceimpl NSObjectProtocol for AVAudioConnectionPoint
impl NSObjectProtocol for AVAudioConnectionPoint
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref