#[repr(transparent)]pub struct AVAudioConverterOutputStatus(pub NSInteger);Available on crate feature
AVAudioConverter only.Expand description
These values are returned from convertToBuffer:error:withInputFromBlock:
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl AVAudioConverterOutputStatus
impl AVAudioConverterOutputStatus
Sourcepub const InputRanDry: Self
pub const InputRanDry: Self
Not enough input was available to satisfy the request at the current time. The output buffer contains as much as could be converted.
Sourcepub const EndOfStream: Self
pub const EndOfStream: Self
The end of stream has been reached. No data was returned.