#[repr(C)]pub struct AVAudioConverterPrimeInfo {
pub leadingFrames: AVAudioFrameCount,
pub trailingFrames: AVAudioFrameCount,
}AVAudioConverter and AVAudioTypes only.Expand description
This struct is the value of the primeInfo property and specifies priming information.
When using convertToBuffer:error:withInputFromBlock: (either a single call or a series of calls), some conversions, particularly involving sample-rate conversion, ideally require a certain number of input frames previous to the normal start input frame and beyond the end of the last expected input frame in order to yield high-quality results.
These are expressed in the leadingFrames and trailingFrames members of the structure.
The very first call to convertToBuffer:error:withInputFromBlock:, or first call after reset, will request additional input frames beyond those normally expected in the input proc callback to fulfill this first AudioConverterFillComplexBuffer() request. The number of additional frames requested, depending on the prime method, will be approximately:
| Prime method | Additional frames |
|---|---|
| AVAudioConverterPrimeMethod_Pre | leadingFrames + trailingFrames |
| AVAudioConverterPrimeMethod_Normal | trailingFrames |
| AVAudioConverterPrimeMethod_None | 0 |
Thus, in effect, the first input proc callback(s) may provide not only the leading frames, but also may “read ahead” by an additional number of trailing frames depending on the prime method.
AVAudioConverterPrimeMethod_None is useful in a real-time application processing live input, in which case trailingFrames (relative to input sample rate) of through latency will be seen at the beginning of the output of the AudioConverter. In other real-time applications such as DAW systems, it may be possible to provide these initial extra audio frames since they are stored on disk or in memory somewhere and AVAudioConverterPrimeMethod_Pre may be preferable. The default method is AVAudioConverterPrimeMethod_Normal, which requires no pre-seeking of the input stream and generates no latency at the output.
Field: leadingFrames Specifies the number of leading (previous) input frames, relative to the normal/desired start input frame, required by the converter to perform a high quality conversion. If using AVAudioConverterPrimeMethod_Pre, the client should “pre-seek” the input stream provided through the input proc by leadingFrames. If no frames are available previous to the desired input start frame (because, for example, the desired start frame is at the very beginning of available audio), then provide “leadingFrames” worth of initial zero frames in the input proc. Do not “pre-seek” in the default case of AVAudioConverterPrimeMethod_Normal or when using AVAudioConverterPrimeMethod_None.
Field: trailingFrames Specifies the number of trailing input frames (past the normal/expected end input frame) required by the converter to perform a high quality conversion. The client should be prepared to provide this number of additional input frames except when using AVAudioConverterPrimeMethod_None. If no more frames of input are available in the input stream (because, for example, the desired end frame is at the end of an audio file), then zero (silent) trailing frames will be synthesized for the client.
See also Apple’s documentation
Fields
leadingFrames: AVAudioFrameCounttrailingFrames: AVAudioFrameCountTrait Implementations
Sourceimpl Clone for AVAudioConverterPrimeInfo
impl Clone for AVAudioConverterPrimeInfo
Sourcefn clone(&self) -> AVAudioConverterPrimeInfo
fn clone(&self) -> AVAudioConverterPrimeInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more