#[repr(transparent)]pub struct AVAudioSessionInterruptionReason(pub NSUInteger);AVAudioSessionTypes only.Expand description
Values for AVAudioSessionInterruptionReasonKey in AVAudioSessionInterruptionNotification’s userInfo dictionary.
The audio session was interrupted because another session was activated.
The audio session was interrupted due to the app being suspended by the operating sytem. Deprecated. Interruption notifications with reason ‘wasSuspended’ not present from iOS 16 onwards.
The audio session was interrupted due to the built-in mic being muted e.g. due to an iPad’s Smart Folio being closed.
The audio session was interrupted due to route getting disconnected.
The audio session was interrupted due to device being doffed or locked.
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl AVAudioSessionInterruptionReason
impl AVAudioSessionInterruptionReason
pub const Default: Self
pub const AppWasSuspended: Self
wasSuspended reason no longer present
pub const BuiltInMicMuted: Self
Sourcepub const RouteDisconnected: Self
pub const RouteDisconnected: Self
The audio session was interrupted because route was disconnected.