AVAudioSessionPortDescription

Struct AVAudioSessionPortDescription 

#[repr(C)]
pub struct AVAudioSessionPortDescription { /* private fields */ }
Available on crate feature AVAudioSessionRoute only.
Information about a port, a physical connector or audio device.

See also Apple’s documentation

Implementations

Source

impl AVAudioSessionPortDescription

pub unsafe fn portType(&self) -> Retained<AVAudioSessionPort>

Available on crate feature AVAudioSessionTypes only.
pub unsafe fn portName(&self) -> Retained<NSString>

A descriptive name for the associated hardware port

pub unsafe fn UID(&self) -> Retained<NSString>

A system-assigned unique identifier for the associated hardware port

pub unsafe fn hasHardwareVoiceCallProcessing(&self) -> bool

This property’s value will be true if the associated hardware port has built-in processing for two-way voice communication.

Applications that use their own proprietary voice processing algorithms should use this property to decide when to disable processing. On the other hand, if using Apple’s Voice Processing I/O unit (subtype kAudioUnitSubType_VoiceProcessingIO), the system will automatically manage this for the application. In particular, ports of type AVAudioSessionPortBluetoothHFP and AVAudioSessionPortCarAudio often have hardware voice processing.

pub unsafe fn isSpatialAudioEnabled(&self) -> bool

This property’s value will be true if the port supports spatial audio playback and the feature is enabled.

‘Now Playing’ apps should also inform the system if they support multichannel audio content using -setSupportsMultichannelContent:error: method. Apps may also register to receive the AVAudioSessionSpatialPlaybackCapabilitiesChanged notification to detect changes in user preferences that affect spatial audio playback.

This property is only relevant in the context of ports that have a small number of hardware channels (typically 2), but have enhanced capabilities for rendering multi-channel content. Note that some port types such as USB and HDMI may support multi-channel playback because they have hardware formats supporting more than 2 channels. For example, many HDMI receivers are connected to multiple speakers and are capable of rendering 5.1, 7.1, or other popular surround sound formats. Applications interested in utilizing multi-channel formats should also query AVAudioSession’s maximumOutputNumberOfChannels property and make use of -setPreferredOutputNumberOfChannels:error: to set the preferred number of hardware channels.

pub unsafe fn channels( &self, ) -> Option<Retained<NSArray<AVAudioSessionChannelDescription>>>

pub unsafe fn dataSources( &self, ) -> Option<Retained<NSArray<AVAudioSessionDataSourceDescription>>>

Will be nil if there are no selectable data sources.

pub unsafe fn selectedDataSource( &self, ) -> Option<Retained<AVAudioSessionDataSourceDescription>>

Will be nil if there are no selectable data sources. In all other cases, this property reflects the currently selected data source.

pub unsafe fn preferredDataSource( &self, ) -> Option<Retained<AVAudioSessionDataSourceDescription>>

This property reflects the application’s preferred data source for the Port. Will be nil if there are no selectable data sources or if no preference has been set.

pub unsafe fn setPreferredDataSource_error( &self, data_source: Option<&AVAudioSessionDataSourceDescription>, ) -> Result<(), Retained<NSError>>

Select the preferred data source for this port. The input dataSource parameter must be one of the dataSources exposed by the dataSources property. Setting a nil value will clear the preference. Note: if the port is part of the active audio route, changing the data source will likely result in a route reconfiguration. If the port is not part of the active route, selecting a new data source will not result in an immediate route reconfiguration. Use AVAudioSession’s -setPreferredInput:error: method to activate the port.

Source

impl AVAudioSessionPortDescription

Methods declared on superclass NSObject.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}