#[repr(transparent)]pub struct AVAudioSessionRecordPermission(pub NSUInteger);Available on crate feature
AVAudioSessionTypes only.Expand description
These are the values returned by recordPermission.
The user has not yet been asked for permission.
The user has been asked and has denied permission.
The user has been asked and has granted permission.
Introduced: ios(8.0), watchos(4.0)
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations