#[repr(transparent)]pub struct AVAudioSessionRouteChangeReason(pub NSUInteger);AVAudioSessionTypes only.Expand description
Values for AVAudioSessionRouteChangeReasonKey in AVAudioSessionRouteChangeNotification’s userInfo dictionary
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl AVAudioSessionRouteChangeReason
impl AVAudioSessionRouteChangeReason
Sourcepub const NewDeviceAvailable: Self
pub const NewDeviceAvailable: Self
A new device became available (e.g. headphones have been plugged in).
The old device became unavailable (e.g. headphones have been unplugged).
Sourcepub const CategoryChange: Self
pub const CategoryChange: Self
The audio category has changed (e.g. AVAudioSessionCategoryPlayback has been changed to AVAudioSessionCategoryPlayAndRecord).
Sourcepub const Override: Self
pub const Override: Self
The route has been overridden (e.g. category is AVAudioSessionCategoryPlayAndRecord and the output has been changed from the receiver, which is the default, to the speaker).
Sourcepub const WakeFromSleep: Self
pub const WakeFromSleep: Self
The device woke from sleep.
Sourcepub const NoSuitableRouteForCategory: Self
pub const NoSuitableRouteForCategory: Self
Returned when there is no route for the current category (for instance, the category is AVAudioSessionCategoryRecord but no input device is available).
Sourcepub const RouteConfigurationChange: Self
pub const RouteConfigurationChange: Self
Indicates that the set of input and/our output ports has not changed, but some aspect of their configuration has changed. For example, a port’s selected data source has changed. (Introduced in iOS 7.0, watchOS 2.0, tvOS 9.0).