#[repr(transparent)]pub struct AVAudioStereoOrientation(pub NSInteger);Available on crate feature
AVAudioSessionTypes only.Expand description
Constants indicating stereo input audio orientation, for use with built-in mic input data sources with a stereo polar pattern selected.
Indicates that audio capture orientation is not applicable (on mono capture, for instance).
Indicates that audio capture should be oriented vertically, Lightning connector on the bottom.
Indicates that audio capture should be oriented vertically, Lightning connector on the top.
Indicates that audio capture should be oriented horizontally, Lightning connector on the right.
Indicates that audio capture should be oriented horizontally, Lightning connector on the left.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl AVAudioStereoOrientation
impl AVAudioStereoOrientation
pub const None: Self
pub const Portrait: Self
pub const PortraitUpsideDown: Self
pub const LandscapeRight: Self
pub const LandscapeLeft: Self