pub struct AVAudioUnitComponentManager { /* private fields */ }AVAudioUnitComponent only.Expand description
A singleton object that provides an easy way to find audio components that are registered with the system.
AVAudioUnitComponentManager provides methods to search and query various information about the audio components without opening them.
Currently audio components that are audio units can only be searched.
The class also supports predefined system tags and arbitrary user tags. Each audio unit can be tagged as part of its definition. Refer to AudioComponent.h for more details. AudioUnit Hosts such as Logic or GarageBand can present groupings of audio units based on the tags.
Searching for audio units can be done in various ways
- using a NSPredicate that contains search strings for tags or descriptions
- using a block to match on custom criteria
- using an AudioComponentDescription
See also Apple’s documentation
Implementations
Sourceimpl AVAudioUnitComponentManager
impl AVAudioUnitComponentManager
Sourcepub unsafe fn tagNames(&self) -> Retained<NSArray<NSString>>
pub unsafe fn tagNames(&self) -> Retained<NSArray<NSString>>
returns all tags associated with the current user as well as all system tags defined by the audio unit(s).
Sourcepub unsafe fn standardLocalizedTagNames(&self) -> Retained<NSArray<NSString>>
pub unsafe fn standardLocalizedTagNames(&self) -> Retained<NSArray<NSString>>
returns the localized standard system tags defined by the audio unit(s).
Sourcepub unsafe fn componentsMatchingPredicate(
&self,
predicate: &NSPredicate,
) -> Retained<NSArray<AVAudioUnitComponent>>
pub unsafe fn componentsMatchingPredicate( &self, predicate: &NSPredicate, ) -> Retained<NSArray<AVAudioUnitComponent>>
returns an array of AVAudioUnitComponent objects that match the search predicate.
AudioComponent’s information or tags can be used to build a search criteria. For example, “typeName CONTAINS ‘Effect’” or tags IN {‘Sampler’, ‘MIDI’}“
Sourcepub unsafe fn componentsPassingTest(
&self,
test_handler: &DynBlock<dyn Fn(NonNull<AVAudioUnitComponent>, NonNull<Bool>) -> Bool>,
) -> Retained<NSArray<AVAudioUnitComponent>>
Available on crate feature block2 only.
pub unsafe fn componentsPassingTest( &self, test_handler: &DynBlock<dyn Fn(NonNull<AVAudioUnitComponent>, NonNull<Bool>) -> Bool>, ) -> Retained<NSArray<AVAudioUnitComponent>>
block2 only.returns an array of AVAudioUnitComponent objects that pass the user provided block method.
For each AudioComponent found by the manager, the block method will be called. If the return value is YES then the AudioComponent is added to the resulting array else it will excluded. This gives more control to the block provider to filter out the components returned.
Sourcepub unsafe fn componentsMatchingDescription(
&self,
desc: AudioComponentDescription,
) -> Retained<NSArray<AVAudioUnitComponent>>
Available on crate feature objc2-audio-toolbox and non-watchOS only.
pub unsafe fn componentsMatchingDescription( &self, desc: AudioComponentDescription, ) -> Retained<NSArray<AVAudioUnitComponent>>
objc2-audio-toolbox and non-watchOS only.returns an array of AVAudioUnitComponent objects that match the description.
This method provides a mechanism to search for AudioComponents using AudioComponentDescription structure. The type, subtype and manufacturer fields are used to search for audio units. A value of 0 for any of these fields is a wildcard and returns the first match found.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for AVAudioUnitComponentManager
impl AsRef<AnyObject> for AVAudioUnitComponentManager
Sourceimpl AsRef<NSObject> for AVAudioUnitComponentManager
impl AsRef<NSObject> for AVAudioUnitComponentManager
Sourceimpl Borrow<NSObject> for AVAudioUnitComponentManager
impl Borrow<NSObject> for AVAudioUnitComponentManager
Sourceimpl ClassType for AVAudioUnitComponentManager
impl ClassType for AVAudioUnitComponentManager
Sourceconst NAME: &'static str = "AVAudioUnitComponentManager"
const NAME: &'static str = "AVAudioUnitComponentManager"
Sourcetype ThreadKind = <<AVAudioUnitComponentManager as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<AVAudioUnitComponentManager as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for AVAudioUnitComponentManager
impl Debug for AVAudioUnitComponentManager
Sourceimpl Deref for AVAudioUnitComponentManager
impl Deref for AVAudioUnitComponentManager
Sourceimpl Hash for AVAudioUnitComponentManager
impl Hash for AVAudioUnitComponentManager
Sourceimpl NSObjectProtocol for AVAudioUnitComponentManager
impl NSObjectProtocol for AVAudioUnitComponentManager
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref