#[repr(C)]pub struct AVAudioVoiceProcessingOtherAudioDuckingConfiguration {
pub enableAdvancedDucking: Bool,
pub duckingLevel: AVAudioVoiceProcessingOtherAudioDuckingLevel,
}Available on crate feature
AVAudioIONode only.Expand description
The configuration of ducking other (i.e. non-voice) audio
Enables advanced ducking which ducks other audio based on the presence of voice activity from local and/or remote chat participants.
Ducking level of other audio
See also Apple’s documentation
Fields
enableAdvancedDucking: BoolduckingLevel: AVAudioVoiceProcessingOtherAudioDuckingLevelTrait Implementations
Sourceimpl Clone for AVAudioVoiceProcessingOtherAudioDuckingConfiguration
impl Clone for AVAudioVoiceProcessingOtherAudioDuckingConfiguration
Sourcefn clone(&self) -> AVAudioVoiceProcessingOtherAudioDuckingConfiguration
fn clone(&self) -> AVAudioVoiceProcessingOtherAudioDuckingConfiguration
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AVAudioVoiceProcessingOtherAudioDuckingConfiguration
impl PartialEq for AVAudioVoiceProcessingOtherAudioDuckingConfiguration
Sourcefn eq(
&self,
other: &AVAudioVoiceProcessingOtherAudioDuckingConfiguration,
) -> bool
fn eq( &self, other: &AVAudioVoiceProcessingOtherAudioDuckingConfiguration, ) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AVAudioVoiceProcessingOtherAudioDuckingConfiguration
impl RefEncode for AVAudioVoiceProcessingOtherAudioDuckingConfiguration
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AVAudioVoiceProcessingOtherAudioDuckingConfiguration
impl StructuralPartialEq for AVAudioVoiceProcessingOtherAudioDuckingConfiguration