#[repr(C)]pub struct AVParameterEvent { /* private fields */ }AVMusicEvents only.Expand description
The event class representing a parameter set/change event on the AVMusicTrack’s destinationAudioUnit.
AVParameterEvents make it possible to schedule and/or automate parameter changes on the audio unit that has been configured as the destination for the AVMusicTrack containing this event.
When the track is played as part of a sequence, the destination audio unit will receive set-parameter messages whose values change smoothly along a linear ramp between each event’s beat location.
If an AVParameterEvent is added to an empty, non-automation track, the track becomes an automation track.
See also Apple’s documentation
Implementations
Sourceimpl AVParameterEvent
impl AVParameterEvent
Sourcepub unsafe fn initWithParameterID_scope_element_value(
this: Allocated<Self>,
parameter_id: u32,
scope: u32,
element: u32,
value: c_float,
) -> Retained<Self>
pub unsafe fn initWithParameterID_scope_element_value( this: Allocated<Self>, parameter_id: u32, scope: u32, element: u32, value: c_float, ) -> Retained<Self>
Initialize the event with the parameter ID, scope, element, and value for the parameter to be set.
Parameter parameterID: The ID of the parameter (see AudioUnitParameterID).
Parameter scope: The audio unit scope for the parameter (see AudioUnitScope).
Parameter element: The element index within the scope (see AudioUnitElement).
Parameter value: The value of the parameter to be set. Range: Dependent on parameter.
Sourcepub unsafe fn parameterID(&self) -> u32
pub unsafe fn parameterID(&self) -> u32
The ID of the parameter (see AudioUnitParameterID).
Sourcepub unsafe fn setParameterID(&self, parameter_id: u32)
pub unsafe fn setParameterID(&self, parameter_id: u32)
Setter for parameterID.
Sourcepub unsafe fn setElement(&self, element: u32)
pub unsafe fn setElement(&self, element: u32)
Setter for element.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AVMusicEvent> for AVParameterEvent
impl AsRef<AVMusicEvent> for AVParameterEvent
Sourcefn as_ref(&self) -> &AVMusicEvent
fn as_ref(&self) -> &AVMusicEvent
Sourceimpl AsRef<AVParameterEvent> for AVParameterEvent
impl AsRef<AVParameterEvent> for AVParameterEvent
Sourceimpl AsRef<AnyObject> for AVParameterEvent
impl AsRef<AnyObject> for AVParameterEvent
Sourceimpl AsRef<NSObject> for AVParameterEvent
impl AsRef<NSObject> for AVParameterEvent
Sourceimpl Borrow<AVMusicEvent> for AVParameterEvent
impl Borrow<AVMusicEvent> for AVParameterEvent
Sourcefn borrow(&self) -> &AVMusicEvent
fn borrow(&self) -> &AVMusicEvent
Sourceimpl Borrow<AnyObject> for AVParameterEvent
impl Borrow<AnyObject> for AVParameterEvent
Sourceimpl Borrow<NSObject> for AVParameterEvent
impl Borrow<NSObject> for AVParameterEvent
Sourceimpl ClassType for AVParameterEvent
impl ClassType for AVParameterEvent
Sourceconst NAME: &'static str = "AVParameterEvent"
const NAME: &'static str = "AVParameterEvent"
Sourcetype Super = AVMusicEvent
type Super = AVMusicEvent
Sourcetype ThreadKind = <<AVParameterEvent as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<AVParameterEvent as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for AVParameterEvent
impl Debug for AVParameterEvent
Sourceimpl Deref for AVParameterEvent
impl Deref for AVParameterEvent
Sourceimpl Hash for AVParameterEvent
impl Hash for AVParameterEvent
Sourceimpl Message for AVParameterEvent
impl Message for AVParameterEvent
Sourceimpl NSObjectProtocol for AVParameterEvent
impl NSObjectProtocol for AVParameterEvent
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref