AVAudioSinkNodeReceiverBlock

Type Alias AVAudioSinkNodeReceiverBlock 

pub type AVAudioSinkNodeReceiverBlock = *mut DynBlock<dyn Fn(NonNull<AudioTimeStamp>, AVAudioFrameCount, NonNull<AudioBufferList>) -> i32>;
Available on crate features AVAudioSinkNode and AVAudioTypes and block2 and objc2-core-audio-types only.
Block to receive audio data from AVAudioSinkNode

Parameter timestamp: The time at which the input data will be rendered.

Parameter frameCount: The number of sample frames of input provided.

Parameter inputData: The input audio data.

The engine will supply valid buffers in inputData’s mBuffers’ mData and mDataByteSize. mDataByteSize will be consistent with frameCount.

The pointer to the AudioBufferList is only valid within the scope of this block.

Returns: An OSStatus result code. If an error is returned, the input data should be assumed to be invalid.

See also Apple’s documentation