#[repr(C)]pub struct AVAudio3DVectorOrientation {
pub forward: AVAudio3DVector,
pub up: AVAudio3DVector,
}Available on crate feature
AVAudioTypes only.Expand description
Struct representing the orientation of the listener in 3D space
Two orthogonal vectors describe the orientation of the listener. The forward vector points in the direction that the listener is facing. The up vector is orthogonal to the forward vector and points upwards from the listener’s head.
See also Apple’s documentation
Fields
forward: AVAudio3DVectorup: AVAudio3DVectorTrait Implementations
Sourceimpl Clone for AVAudio3DVectorOrientation
impl Clone for AVAudio3DVectorOrientation
Sourcefn clone(&self) -> AVAudio3DVectorOrientation
fn clone(&self) -> AVAudio3DVectorOrientation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AVAudio3DVectorOrientation
impl Debug for AVAudio3DVectorOrientation
Sourceimpl Encode for AVAudio3DVectorOrientation
impl Encode for AVAudio3DVectorOrientation
Sourceimpl RefEncode for AVAudio3DVectorOrientation
impl RefEncode for AVAudio3DVectorOrientation
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AVAudio3DVectorOrientation
impl StructuralPartialEq for AVAudio3DVectorOrientation