#[repr(C)]pub struct AVAudioConverter { /* private fields */ }AVAudioConverter only.Expand description
Converts streams of audio between various formats.
See also Apple’s documentation
Implementations
Sourceimpl AVAudioConverter
impl AVAudioConverter
Sourcepub unsafe fn initFromFormat_toFormat(
this: Allocated<Self>,
from_format: &AVAudioFormat,
to_format: &AVAudioFormat,
) -> Option<Retained<Self>>
Available on crate feature AVAudioFormat only.
pub unsafe fn initFromFormat_toFormat( this: Allocated<Self>, from_format: &AVAudioFormat, to_format: &AVAudioFormat, ) -> Option<Retained<Self>>
AVAudioFormat only.Initialize from input and output formats.
Parameter fromFormat: The input format.
Parameter toFormat: The output format.
Returns nil if the format conversion is not possible.
Sourcepub unsafe fn inputFormat(&self) -> Retained<AVAudioFormat>
Available on crate feature AVAudioFormat only.
pub unsafe fn inputFormat(&self) -> Retained<AVAudioFormat>
AVAudioFormat only.The format of the input audio stream. (NB. AVAudioFormat includes the channel layout)
Sourcepub unsafe fn outputFormat(&self) -> Retained<AVAudioFormat>
Available on crate feature AVAudioFormat only.
pub unsafe fn outputFormat(&self) -> Retained<AVAudioFormat>
AVAudioFormat only.The format of the output audio stream. (NB. AVAudioFormat includes the channel layout)
Sourcepub unsafe fn channelMap(&self) -> Retained<NSArray<NSNumber>>
pub unsafe fn channelMap(&self) -> Retained<NSArray<NSNumber>>
An array of integers indicating from which input to derive each output.
The array has size equal to the number of output channels. Each element’s value is the input channel number, starting with zero, that is to be copied to that output. A negative value means that the output channel will have no source and will be silent. Setting a channel map overrides channel mapping due to any channel layouts in the input and output formats that may have been supplied.
Sourcepub unsafe fn setChannelMap(&self, channel_map: &NSArray<NSNumber>)
pub unsafe fn setChannelMap(&self, channel_map: &NSArray<NSNumber>)
Setter for channelMap.
Sourcepub unsafe fn magicCookie(&self) -> Option<Retained<NSData>>
pub unsafe fn magicCookie(&self) -> Option<Retained<NSData>>
Decoders require some data in the form of a magicCookie in order to decode properly. Encoders will produce a magicCookie.
Sourcepub unsafe fn setMagicCookie(&self, magic_cookie: Option<&NSData>)
pub unsafe fn setMagicCookie(&self, magic_cookie: Option<&NSData>)
Setter for magicCookie.
Sourcepub unsafe fn downmix(&self) -> bool
pub unsafe fn downmix(&self) -> bool
If YES and channel remapping is necessary, then channels will be mixed as appropriate instead of remapped. Default value is NO.
Sourcepub unsafe fn setDownmix(&self, downmix: bool)
pub unsafe fn setDownmix(&self, downmix: bool)
Setter for downmix.
Sourcepub unsafe fn dither(&self) -> bool
pub unsafe fn dither(&self) -> bool
Setting YES will turn on dither, if dither makes sense in given the current formats and settings. Default value is NO.
Sourcepub unsafe fn sampleRateConverterQuality(&self) -> NSInteger
pub unsafe fn sampleRateConverterQuality(&self) -> NSInteger
An AVAudioQuality value as defined in AVAudioSettings.h.
Sourcepub unsafe fn setSampleRateConverterQuality(
&self,
sample_rate_converter_quality: NSInteger,
)
pub unsafe fn setSampleRateConverterQuality( &self, sample_rate_converter_quality: NSInteger, )
Setter for sampleRateConverterQuality.
Sourcepub unsafe fn sampleRateConverterAlgorithm(&self) -> Option<Retained<NSString>>
pub unsafe fn sampleRateConverterAlgorithm(&self) -> Option<Retained<NSString>>
An AVSampleRateConverterAlgorithmKey value as defined in AVAudioSettings.h.
Sourcepub unsafe fn setSampleRateConverterAlgorithm(
&self,
sample_rate_converter_algorithm: Option<&NSString>,
)
pub unsafe fn setSampleRateConverterAlgorithm( &self, sample_rate_converter_algorithm: Option<&NSString>, )
Setter for sampleRateConverterAlgorithm.
Sourcepub unsafe fn primeMethod(&self) -> AVAudioConverterPrimeMethod
pub unsafe fn primeMethod(&self) -> AVAudioConverterPrimeMethod
Indicates the priming method to be used by the sample rate converter or decoder.
Sourcepub unsafe fn setPrimeMethod(&self, prime_method: AVAudioConverterPrimeMethod)
pub unsafe fn setPrimeMethod(&self, prime_method: AVAudioConverterPrimeMethod)
Setter for primeMethod.
Sourcepub unsafe fn primeInfo(&self) -> AVAudioConverterPrimeInfo
Available on crate feature AVAudioTypes only.
pub unsafe fn primeInfo(&self) -> AVAudioConverterPrimeInfo
AVAudioTypes only.Indicates the the number of priming frames.
Sourcepub unsafe fn setPrimeInfo(&self, prime_info: AVAudioConverterPrimeInfo)
Available on crate feature AVAudioTypes only.
pub unsafe fn setPrimeInfo(&self, prime_info: AVAudioConverterPrimeInfo)
AVAudioTypes only.Setter for primeInfo.
Sourcepub unsafe fn convertToBuffer_fromBuffer_error(
&self,
output_buffer: &AVAudioPCMBuffer,
input_buffer: &AVAudioPCMBuffer,
) -> Result<(), Retained<NSError>>
Available on crate feature AVAudioBuffer only.
pub unsafe fn convertToBuffer_fromBuffer_error( &self, output_buffer: &AVAudioPCMBuffer, input_buffer: &AVAudioPCMBuffer, ) -> Result<(), Retained<NSError>>
AVAudioBuffer only.Perform a simple conversion. That is, a conversion which does not involve codecs or sample rate conversion.
Parameter inputBuffer: The input buffer.
Parameter outputBuffer: The output buffer.
Parameter outError: An error if the conversion fails.
Returns: YES is returned on success, NO when an error has occurred.
The output buffer’s frameCapacity should be at least at large as the inputBuffer’s frameLength. If the conversion involves a codec or sample rate conversion, you instead must use convertToBuffer:error:withInputFromBlock:.
Sourcepub unsafe fn convertToBuffer_error_withInputFromBlock(
&self,
output_buffer: &AVAudioBuffer,
out_error: Option<&mut Option<Retained<NSError>>>,
input_block: AVAudioConverterInputBlock,
) -> AVAudioConverterOutputStatus
Available on crate features AVAudioBuffer and AVAudioTypes and block2 only.
pub unsafe fn convertToBuffer_error_withInputFromBlock( &self, output_buffer: &AVAudioBuffer, out_error: Option<&mut Option<Retained<NSError>>>, input_block: AVAudioConverterInputBlock, ) -> AVAudioConverterOutputStatus
AVAudioBuffer and AVAudioTypes and block2 only.Perform any supported conversion.
Parameter inputBlock: A block which will be called to get input data as needed. See description for AVAudioConverterInputBlock.
Parameter outputBuffer: The output buffer.
Parameter outError: An error if the conversion fails.
Returns: An AVAudioConverterOutputStatus is returned.
It attempts to fill the buffer to its capacity. On return, the buffer’s length indicates the number of sample frames successfully converted.
Sourceimpl AVAudioConverter
Methods declared on superclass NSObject.
impl AVAudioConverter
Methods declared on superclass NSObject.
Sourceimpl AVAudioConverter
Encoding.
impl AVAudioConverter
Encoding.
Sourcepub unsafe fn bitRate(&self) -> NSInteger
pub unsafe fn bitRate(&self) -> NSInteger
bitRate in bits per second. Only applies when encoding.
Sourcepub unsafe fn setBitRate(&self, bit_rate: NSInteger)
pub unsafe fn setBitRate(&self, bit_rate: NSInteger)
Setter for bitRate.
Sourcepub unsafe fn bitRateStrategy(&self) -> Option<Retained<NSString>>
pub unsafe fn bitRateStrategy(&self) -> Option<Retained<NSString>>
When encoding, an AVEncoderBitRateStrategyKey value constant as defined in AVAudioSettings.h. Returns nil if not encoding.
Sourcepub unsafe fn setBitRateStrategy(&self, bit_rate_strategy: Option<&NSString>)
pub unsafe fn setBitRateStrategy(&self, bit_rate_strategy: Option<&NSString>)
Setter for bitRateStrategy.
Sourcepub unsafe fn maximumOutputPacketSize(&self) -> NSInteger
pub unsafe fn maximumOutputPacketSize(&self) -> NSInteger
The maximum size of an output packet, in bytes.
When encoding it is useful to know how large a packet can be in order to allocate a buffer to receive the output.
Sourcepub unsafe fn availableEncodeBitRates(
&self,
) -> Option<Retained<NSArray<NSNumber>>>
pub unsafe fn availableEncodeBitRates( &self, ) -> Option<Retained<NSArray<NSNumber>>>
When encoding, an NSArray of NSNumber of all bit rates provided by the codec. Returns nil if not encoding.
Sourcepub unsafe fn applicableEncodeBitRates(
&self,
) -> Option<Retained<NSArray<NSNumber>>>
pub unsafe fn applicableEncodeBitRates( &self, ) -> Option<Retained<NSArray<NSNumber>>>
When encoding, an NSArray of NSNumber of bit rates that can be applied based on the current formats and settings. Returns nil if not encoding.
Sourcepub unsafe fn availableEncodeSampleRates(
&self,
) -> Option<Retained<NSArray<NSNumber>>>
pub unsafe fn availableEncodeSampleRates( &self, ) -> Option<Retained<NSArray<NSNumber>>>
When encoding, an NSArray of NSNumber of all output sample rates provided by the codec. Returns nil if not encoding.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AVAudioConverter> for AVAudioConverter
impl AsRef<AVAudioConverter> for AVAudioConverter
Sourceimpl AsRef<AnyObject> for AVAudioConverter
impl AsRef<AnyObject> for AVAudioConverter
Sourceimpl AsRef<NSObject> for AVAudioConverter
impl AsRef<NSObject> for AVAudioConverter
Sourceimpl Borrow<AnyObject> for AVAudioConverter
impl Borrow<AnyObject> for AVAudioConverter
Sourceimpl Borrow<NSObject> for AVAudioConverter
impl Borrow<NSObject> for AVAudioConverter
Sourceimpl ClassType for AVAudioConverter
impl ClassType for AVAudioConverter
Sourceconst NAME: &'static str = "AVAudioConverter"
const NAME: &'static str = "AVAudioConverter"
Sourcetype ThreadKind = <<AVAudioConverter as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<AVAudioConverter as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for AVAudioConverter
impl Debug for AVAudioConverter
Sourceimpl Deref for AVAudioConverter
impl Deref for AVAudioConverter
Sourceimpl Hash for AVAudioConverter
impl Hash for AVAudioConverter
Sourceimpl Message for AVAudioConverter
impl Message for AVAudioConverter
Sourceimpl NSObjectProtocol for AVAudioConverter
impl NSObjectProtocol for AVAudioConverter
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref