#[repr(transparent)]pub struct AVAudioEngineManualRenderingError(pub i32);AVAudioEngine only.Expand description
Error codes that could be returned from AVAudioEngine manual rendering mode methods,
e.g. enableManualRenderingMode:format:maximumFrameCount:error: and
renderOffline:toBuffer:error:.
Note that this is not a comprehensive list, and the underlying audio units could
return other error codes (e.g. see kAudioUnitErr_* in AudioToolbox/AUComponent.h) from these
methods as applicable.
AVAudioEngineManualRenderingErrorInvalidMode The operation cannot be performed because the engine is either not in manual rendering mode or the right variant of it.
AVAudioEngineManualRenderingErrorInitialized The operation cannot be performed because the engine is initialized (i.e. not stopped).
AVAudioEngineManualRenderingErrorNotRunning The operation cannot be performed because the engine is not running (i.e. not started).
See also Apple’s documentation
Tuple Fields
0: i32Implementations