#[repr(C)]pub struct AVAudioMixingDestination { /* private fields */ }AVAudioMixing only.Expand description
An object representing a connection to a mixer node from a node that conforms to AVAudioMixing protocol
A standalone instance of AVAudioMixingDestination cannot be created.
Only an instance vended by a source node (e.g. AVAudioPlayerNode) can be used
(see AVAudioMixing).
See also Apple’s documentation
Implementations
Sourceimpl AVAudioMixingDestination
impl AVAudioMixingDestination
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn connectionPoint(&self) -> Retained<AVAudioConnectionPoint>
Available on crate feature AVAudioConnectionPoint only.
pub unsafe fn connectionPoint(&self) -> Retained<AVAudioConnectionPoint>
AVAudioConnectionPoint only.Returns the underlying mixer connection point
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AVAudio3DMixing for AVAudioMixingDestination
impl AVAudio3DMixing for AVAudioMixingDestination
Sourceunsafe fn renderingAlgorithm(&self) -> AVAudio3DMixingRenderingAlgorithm
unsafe fn renderingAlgorithm(&self) -> AVAudio3DMixingRenderingAlgorithm
Sourceunsafe fn setRenderingAlgorithm(
&self,
rendering_algorithm: AVAudio3DMixingRenderingAlgorithm,
)
unsafe fn setRenderingAlgorithm( &self, rendering_algorithm: AVAudio3DMixingRenderingAlgorithm, )
renderingAlgorithm.Sourceunsafe fn sourceMode(&self) -> AVAudio3DMixingSourceMode
unsafe fn sourceMode(&self) -> AVAudio3DMixingSourceMode
Sourceunsafe fn setSourceMode(&self, source_mode: AVAudio3DMixingSourceMode)
unsafe fn setSourceMode(&self, source_mode: AVAudio3DMixingSourceMode)
sourceMode.Sourceunsafe fn pointSourceInHeadMode(&self) -> AVAudio3DMixingPointSourceInHeadMode
unsafe fn pointSourceInHeadMode(&self) -> AVAudio3DMixingPointSourceInHeadMode
Sourceunsafe fn setPointSourceInHeadMode(
&self,
point_source_in_head_mode: AVAudio3DMixingPointSourceInHeadMode,
)
unsafe fn setPointSourceInHeadMode( &self, point_source_in_head_mode: AVAudio3DMixingPointSourceInHeadMode, )
pointSourceInHeadMode.Sourceunsafe fn reverbBlend(&self) -> c_float
unsafe fn reverbBlend(&self) -> c_float
Sourceunsafe fn setReverbBlend(&self, reverb_blend: c_float)
unsafe fn setReverbBlend(&self, reverb_blend: c_float)
reverbBlend.Sourceunsafe fn obstruction(&self) -> c_float
unsafe fn obstruction(&self) -> c_float
Sourceunsafe fn setObstruction(&self, obstruction: c_float)
unsafe fn setObstruction(&self, obstruction: c_float)
obstruction.Sourceunsafe fn occlusion(&self) -> c_float
unsafe fn occlusion(&self) -> c_float
Sourceunsafe fn setOcclusion(&self, occlusion: c_float)
unsafe fn setOcclusion(&self, occlusion: c_float)
occlusion.Sourceunsafe fn position(&self) -> AVAudio3DPoint
unsafe fn position(&self) -> AVAudio3DPoint
AVAudioTypes only.Sourceunsafe fn setPosition(&self, position: AVAudio3DPoint)
unsafe fn setPosition(&self, position: AVAudio3DPoint)
AVAudioTypes only.position.Sourceimpl AVAudioMixing for AVAudioMixingDestination
impl AVAudioMixing for AVAudioMixingDestination
Sourceunsafe fn destinationForMixer_bus(
&self,
mixer: &AVAudioNode,
bus: AVAudioNodeBus,
) -> Option<Retained<AVAudioMixingDestination>>
unsafe fn destinationForMixer_bus( &self, mixer: &AVAudioNode, bus: AVAudioNodeBus, ) -> Option<Retained<AVAudioMixingDestination>>
AVAudioNode and AVAudioTypes only.Sourceimpl AsRef<AnyObject> for AVAudioMixingDestination
impl AsRef<AnyObject> for AVAudioMixingDestination
Sourceimpl AsRef<NSObject> for AVAudioMixingDestination
impl AsRef<NSObject> for AVAudioMixingDestination
Sourceimpl Borrow<AnyObject> for AVAudioMixingDestination
impl Borrow<AnyObject> for AVAudioMixingDestination
Sourceimpl Borrow<NSObject> for AVAudioMixingDestination
impl Borrow<NSObject> for AVAudioMixingDestination
Sourceimpl ClassType for AVAudioMixingDestination
impl ClassType for AVAudioMixingDestination
Sourceconst NAME: &'static str = "AVAudioMixingDestination"
const NAME: &'static str = "AVAudioMixingDestination"
Sourcetype ThreadKind = <<AVAudioMixingDestination as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<AVAudioMixingDestination as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for AVAudioMixingDestination
impl Debug for AVAudioMixingDestination
Sourceimpl Deref for AVAudioMixingDestination
impl Deref for AVAudioMixingDestination
Sourceimpl Hash for AVAudioMixingDestination
impl Hash for AVAudioMixingDestination
Sourceimpl Message for AVAudioMixingDestination
impl Message for AVAudioMixingDestination
Sourceimpl NSObjectProtocol for AVAudioMixingDestination
impl NSObjectProtocol for AVAudioMixingDestination
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref