Struct AVAudioRoutingArbitrationCategory

#[repr(transparent)]
pub struct AVAudioRoutingArbitrationCategory(pub NSInteger);
Available on crate feature AVAudioRoutingArbiter only.
The category describes the general type of audio that the app plans to use.

Provides context to the operating system about the type of audio an application intends to use. The system uses this information when arbitrating between Apple products that want to take ownership of Bluetooth audio routes.

Used for Audio playback.

Used for recording and playing back audio.

Appropriate for Voice over IP(VoIP) applications.

See also Apple’s documentation

Tuple Fields

0: NSInteger

Implementations