#[repr(C)]pub struct AVMIDINoteEvent { /* private fields */ }AVMusicEvents only.Expand description
The event class representing MIDI note-on/off messages.
Parameter channel: The MIDI channel for the note. Range: 0-15.
Parameter key: The MIDI key number for the note. Range: 0-127.
Parameter velocity: The MIDI velocity for the note. Range: 0-127 (see discussion).
Parameter duration: The duration of this note event in AVMusicTimeStamp beats. Range: Any non-negative number.
The AVAudioSequencer will automatically send a MIDI note-off after the note duration has passed. To send an explicit note-off event, create an AVMIDINoteEvent with its velocity set to zero.
See also Apple’s documentation
Implementations
Sourceimpl AVMIDINoteEvent
impl AVMIDINoteEvent
Sourcepub unsafe fn initWithChannel_key_velocity_duration(
this: Allocated<Self>,
channel: u32,
key_num: u32,
velocity: u32,
duration: AVMusicTimeStamp,
) -> Retained<Self>
Available on crate feature AVAudioTypes only.
pub unsafe fn initWithChannel_key_velocity_duration( this: Allocated<Self>, channel: u32, key_num: u32, velocity: u32, duration: AVMusicTimeStamp, ) -> Retained<Self>
AVAudioTypes only.Initialize the event with a MIDI channel, key number, velocity and duration.
Parameter channel: The MIDI channel. Range: 0-15.
Parameter key: The MIDI key number. Range: 0-127.
Parameter velocity: The MIDI velocity. Range: 0-127 with zero indicating a note-off event.
Parameter duration: The duration in beats for this note. Range: Any non-negative number.
Sourcepub unsafe fn setChannel(&self, channel: u32)
pub unsafe fn setChannel(&self, channel: u32)
Setter for channel.
Sourcepub unsafe fn setVelocity(&self, velocity: u32)
pub unsafe fn setVelocity(&self, velocity: u32)
Setter for velocity.
Sourcepub unsafe fn duration(&self) -> AVMusicTimeStamp
Available on crate feature AVAudioTypes only.
pub unsafe fn duration(&self) -> AVMusicTimeStamp
AVAudioTypes only.The duration of the event in AVMusicTimeStamp beats. Range: Any non-negative number.
Sourcepub unsafe fn setDuration(&self, duration: AVMusicTimeStamp)
Available on crate feature AVAudioTypes only.
pub unsafe fn setDuration(&self, duration: AVMusicTimeStamp)
AVAudioTypes only.Setter for duration.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AVMIDINoteEvent> for AVMIDINoteEvent
impl AsRef<AVMIDINoteEvent> for AVMIDINoteEvent
Sourceimpl AsRef<AVMusicEvent> for AVMIDINoteEvent
impl AsRef<AVMusicEvent> for AVMIDINoteEvent
Sourcefn as_ref(&self) -> &AVMusicEvent
fn as_ref(&self) -> &AVMusicEvent
Sourceimpl AsRef<AnyObject> for AVMIDINoteEvent
impl AsRef<AnyObject> for AVMIDINoteEvent
Sourceimpl AsRef<NSObject> for AVMIDINoteEvent
impl AsRef<NSObject> for AVMIDINoteEvent
Sourceimpl Borrow<AVMusicEvent> for AVMIDINoteEvent
impl Borrow<AVMusicEvent> for AVMIDINoteEvent
Sourcefn borrow(&self) -> &AVMusicEvent
fn borrow(&self) -> &AVMusicEvent
Sourceimpl Borrow<AnyObject> for AVMIDINoteEvent
impl Borrow<AnyObject> for AVMIDINoteEvent
Sourceimpl Borrow<NSObject> for AVMIDINoteEvent
impl Borrow<NSObject> for AVMIDINoteEvent
Sourceimpl ClassType for AVMIDINoteEvent
impl ClassType for AVMIDINoteEvent
Sourceconst NAME: &'static str = "AVMIDINoteEvent"
const NAME: &'static str = "AVMIDINoteEvent"
Sourcetype Super = AVMusicEvent
type Super = AVMusicEvent
Sourcetype ThreadKind = <<AVMIDINoteEvent as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<AVMIDINoteEvent as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for AVMIDINoteEvent
impl Debug for AVMIDINoteEvent
Sourceimpl Deref for AVMIDINoteEvent
impl Deref for AVMIDINoteEvent
Sourceimpl Hash for AVMIDINoteEvent
impl Hash for AVMIDINoteEvent
Sourceimpl Message for AVMIDINoteEvent
impl Message for AVMIDINoteEvent
Sourceimpl NSObjectProtocol for AVMIDINoteEvent
impl NSObjectProtocol for AVMIDINoteEvent
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref