pub unsafe trait AVAudioRecorderDelegate: NSObjectProtocol {
// Provided methods
unsafe fn audioRecorderDidFinishRecording_successfully(
&self,
recorder: &AVAudioRecorder,
flag: bool,
)
where Self: Sized + Message { ... }
unsafe fn audioRecorderEncodeErrorDidOccur_error(
&self,
recorder: &AVAudioRecorder,
error: Option<&NSError>,
)
where Self: Sized + Message { ... }
}Available on crate feature
AVAudioRecorder only.Expand description
A protocol for delegates of AVAudioRecorder.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn audioRecorderDidFinishRecording_successfully(
&self,
recorder: &AVAudioRecorder,
flag: bool,
)
unsafe fn audioRecorderDidFinishRecording_successfully( &self, recorder: &AVAudioRecorder, flag: bool, )
This callback method is called when a recording has been finished or stopped.
This method is NOT called if the recorder is stopped due to an interruption.
Sourceunsafe fn audioRecorderEncodeErrorDidOccur_error(
&self,
recorder: &AVAudioRecorder,
error: Option<&NSError>,
)
unsafe fn audioRecorderEncodeErrorDidOccur_error( &self, recorder: &AVAudioRecorder, error: Option<&NSError>, )
This callback method is called when an error occurs while encoding.
If an error occurs while encoding it will be reported to the delegate.