pub type AVAudioNodeTapBlock = *mut Block<dyn Fn(NonNull<AVAudioPCMBuffer>, NonNull<AVAudioTime>)>;Available on crate features
AVAudioBuffer and AVAudioNode and AVAudioTime and block2 only.Expand description
A block that receives copies of the output of an AVAudioNode.
Parameter buffer: a buffer of audio captured from the output of an AVAudioNode
Parameter when: the time at which the buffer was captured
CAUTION: This callback may be invoked on a thread other than the main thread.
See also Appleās documentation