Type Alias AVAudioSessionMode

pub type AVAudioSessionMode = NSString;
Available on crate feature AVAudioSessionTypes only.
Modes modify the audio category in order to introduce behavior that is tailored to the specific use of audio within an application. Available in iOS 5.0 and greater.

See also Apple’s documentation

Aliased Type

struct AVAudioSessionMode { /* private fields */ }