pub type AVMusicEventEnumerationBlock = *mut Block<dyn Fn(NonNull<AVMusicEvent>, NonNull<AVMusicTimeStamp>, NonNull<Bool>)>;Available on crate features
AVAudioSequencer and AVAudioTypes and AVMusicEvents and block2 only.Expand description
The block type used to enumerate and optionally remove AVMusicEvents when using
AVMusicTrack(enumerateEventsInRange:usingBlock:)
Parameter event: the AVMusicEvent returned by this enumeration block call. If this
event is modified by the block, the corresponding track event will be changed.
Parameter timeStamp: the beat position of this event in the AVMusicTrack. If the block
sets *timeStamp to a new value, the corresponding event’s beat position
in the track will be updated.
Parameter removeEvent: If the block sets *removeEvent to YES, the current event will be
removed from the track.
See also Apple’s documentation